@@ -39,13 +39,6 @@ class MaxRetriesExceededError(Exception):
     """
 
 
-class OverwriteError(Exception):
-    """Raised when saving a DynamoDBModel instance would overwrite something
-    in the database and we've forbidden that because we believe we're creating
-    a new one (see :meth:`DynamoDBModel.save`).
-    """
-
-
 class ConflictError(Exception):
     """Atomic edition failure.
     Raised when an Item has been changed between the read and the write operation
@@ -55,6 +48,13 @@ class ConflictError(Exception):
     """
 
 
+class OverwriteError(ConflictError):
+    """Raised when saving a DynamoDBModel instance would overwrite something
+    in the database and we've forbidden that because we believe we're creating
+    a new one (see :meth:`DynamoDBModel.save`).
+    """
+
+
 class InvalidRegionError(Exception):
     """Raised when ``set_region()`` is called with an invalid region name.
     """
@@ -278,13 +278,6 @@ class ConnectionBorg(object):
             )
         return self._connection
 
-    def _create_autoincrement_magic_item(self, table):
-        item = table.new_item(hash_key=MAGIC_KEY, attrs={
-            "__max_hash_key__": 0
-        })
-        # Conditional write: don't risk overwriting the DB.
-        item.put({item.hash_key_name: False})
-
     def set_credentials(self, aws_access_key_id, aws_secret_access_key):
         """Set the DynamoDB credentials. If boto is already configured on this
         machine, this step is optional.
@@ -378,9 +371,6 @@ class ConnectionBorg(object):
         table = conn.create_table(cls.__table__, schema, read_units, write_units)
         table.refresh(wait_for_active=wait_for_active)
 
-        if hash_key_type is autoincrement_int:
-            self._create_autoincrement_magic_item(table)
-
         dblog.debug("Created table %s(%s, %s)", cls.__table__, hash_key_name, range_key_name)
 
         return table
@@ -495,7 +485,9 @@ class DynamoDBModel(object):
                 default = kwargs.get(name)
             else:
                 default = defaults[name] if name in defaults else None
-            setattr(self, name, _get_default_value(type_, default, name=name))
+            value = _dynamodb_to_python(type_, default) # just in case, ensure types. help migration from 'from_dict'
+            value = _get_default_value(type_, value, name=name)
+            setattr(self, name, value)
 
         # instanciate the migrator only once per model *after* initialization
         if isinstance(cls.__migrator__, type):
@@ -802,10 +794,10 @@ class DynamoDBModel(object):
             one of the original values doesn't match what is in the database
             (i.e. someone went ahead and modified the object in the DB behind
             your back), the operation fails and raises
-            :class:`ConflictError`.
+            :class:`ConflictError` or ``OverwriteError``.
 
         :raise ConflictError: Target object has changed between read and write operation
-        :raise OverwriteError: Saving a new object but it already existed
+        :raise OverwriteError: A new Item overwrites an existing one and ``raise_on_conflict=True``. Note: this exception inherits from ConflictError
         """
 
         cls = type(self)
