@@ -662,6 +662,18 @@ class TestDynamoDBModel(unittest.TestCase):
         self.assertEqual(1, d.id)
         self.assertEqual(u"Knee-deep in the Dead", d.name)
 
+    def test_init_from_unicode_kwargs(self):
+        # regression test for bug #17
+        kwargs = {
+            u'id': u'1',
+            u'name': u'Knee-deep in the Dead',
+        }
+
+        d = DoomEpisode(**kwargs)
+        self.assertEqual({}, d._raw_data)
+        self.assertEqual(1, d.id)
+        self.assertEqual(u"Knee-deep in the Dead", d.name)
+
     def test_build_from_dict(self):
         #FIXME: can it be removed as this feature is implicitly tested elsewhere ?
         d_dict = {"id": 1, "name": "Knee-deep in the Dead"}
